/**
 * Copyright (c) 2017-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.util.jaxb;

import javax.activation.DataHandler;
import javax.jbi.messaging.MessagingException;
import javax.jbi.messaging.NormalizedMessage;

import com.ebmwebsourcing.easycommons.xml.jaxb.AbstractAttachmentMarshaller;

public class JBIAttachmentMarshaller extends AbstractAttachmentMarshaller {

    private final NormalizedMessage message;

    private final boolean reuseDataHandlerName;

    public JBIAttachmentMarshaller(final NormalizedMessage message) {
        this(message, false);
    }

    public JBIAttachmentMarshaller(final NormalizedMessage message, final boolean reuseDataHandlerName) {
        this.message = message;
        this.reuseDataHandlerName = reuseDataHandlerName;
    }

    @Override
    public String addMtomAttachment(final DataHandler data, final String elementNamespace,
            final String elementLocalName) {
        final String dhName = data.getName();
        if (this.reuseDataHandlerName || dhName == null || dhName.isEmpty()) {
            return super.addMtomAttachment(data, elementNamespace, elementLocalName);
        } else {
            this.addAttachment(dhName, data);
            return "cid:" + dhName;
        }
    }

    @Override
    protected void addAttachment(String cid, DataHandler data) {
        try {
            this.message.addAttachment(cid, data);
        } catch (MessagingException e) {
            throw new AssertionError("can't happen", e);
        }
    }
}
